@@ -21,10 +21,10 @@ from typing import Any, Literal, Optional, Union
 import pydantic
 
 from ... import upcast
-from . import commands, oci
+from . import commands
 from .base import DyffBaseModel, JsonMergePatchSemantics
 from .platform import (
-    AnalysisBase,
+    AnalysisRequestBase,
     AnalysisScope,
     ChallengeContent,
     ChallengeTaskBase,
@@ -32,9 +32,9 @@ from .platform import (
     DatasetBase,
     DataView,
     DocumentationBase,
-    EntityIDField,
     Evaluation,
-    EvaluationBase,
+    EvaluationInferenceSessionRequest,
+    EvaluationRequestBase,
     FamilyBase,
     FamilyMemberBase,
     InferenceServiceBase,
@@ -42,8 +42,11 @@ from .platform import (
     MethodBase,
     ModelSpec,
     ModuleBase,
+    PipelineBase,
+    PipelineRunBase,
     ReportBase,
     TagNameType,
+    TeamBase,
     summary_maxlen,
     title_maxlen,
 )
@@ -110,12 +113,10 @@ class DyffEntityCreateRequest(DyffRequestBase):
     account: str = pydantic.Field(description="Account that owns the entity")
 
 
-class AnalysisCreateRequest(DyffEntityCreateRequest, AnalysisBase):
+class AnalysisCreateRequest(DyffEntityCreateRequest, AnalysisRequestBase):
     """An Analysis transforms Datasets, Evaluations, and Measurements into new
     Measurements or SafetyCases."""
 
-    method: EntityIDField = pydantic.Field(description="Method ID")
-
     @pydantic.field_validator("scope", check_fields=False)
     def _validate_scope(cls, scope: AnalysisScope) -> AnalysisScope:
         # TODO: This has to be a validator function because we can't apply the
@@ -151,6 +152,10 @@ class ChallengeTaskCreateRequest(DyffEntityCreateRequest, ChallengeTaskBase):
     pass
 
 
+class ChallengeTeamCreateRequest(DyffEntityCreateRequest, TeamBase):
+    pass
+
+
 class ConcernCreateRequest(DyffEntityCreateRequest, ConcernBase):
     @pydantic.field_validator("documentation", check_fields=False)
     def _validate_documentation(
@@ -208,40 +213,15 @@ class InferenceSessionTokenCreateRequest(DyffRequestBase):
     )
 
 
-class EvaluationInferenceSessionRequest(InferenceSessionBase):
-    inferenceService: str = pydantic.Field(description="InferenceService ID")
-
-
-class EvaluationCreateRequest(DyffEntityCreateRequest, EvaluationBase):
+class EvaluationCreateRequest(DyffEntityCreateRequest, EvaluationRequestBase):
     """A description of how to run an InferenceService on a Dataset to obtain a set of
     evaluation results."""
 
-    inferenceSession: Optional[EvaluationInferenceSessionRequest] = pydantic.Field(
-        default=None,
-        description="Specification of the InferenceSession that will perform inference for the evaluation.",
-    )
-
-    inferenceSessionReference: Optional[str] = pydantic.Field(
-        default=None,
-        description="The ID of a running inference session that will be used"
-        " for the evaluation, instead of starting a new one.",
-    )
-
-    @pydantic.model_validator(mode="after")
-    def check_session_exactly_one(self):
-        session = self.inferenceSession is not None
-        session_ref = self.inferenceSessionReference is not None
-        if not (session ^ session_ref):
-            raise ValueError(
-                "must specify exactly one of {inferenceSession, inferenceSessionReference}"
-            )
-        return self
-
     @staticmethod
     def repeat_of(evaluation: Evaluation) -> EvaluationCreateRequest:
         """Return a request that will run an existing Evaluation again with the same
         configuration."""
-        base = upcast(EvaluationBase, evaluation)
+        base = upcast(EvaluationRequestBase, evaluation)
         if evaluation.inferenceSessionReference:
             return EvaluationCreateRequest(
                 account=evaluation.account,
@@ -277,6 +257,14 @@ class ModuleCreateRequest(DyffEntityCreateRequest, ModuleBase):
     pass
 
 
+class PipelineCreateRequest(DyffEntityCreateRequest, PipelineBase):
+    pass
+
+
+class PipelineRunRequest(DyffEntityCreateRequest, PipelineRunBase):
+    pass
+
+
 class ReportCreateRequest(DyffEntityCreateRequest, ReportBase):
     """A Report transforms raw model outputs into some useful statistics.
 
@@ -305,6 +293,10 @@ class ChallengeContentEditRequest(DyffRequestBase, commands.EditChallengeContent
     pass
 
 
+class ChallengeTaskRulesEditRequest(DyffRequestBase, commands.ChallengeTaskRulesPatch):
+    pass
+
+
 class DocumentationEditRequest(
     DyffRequestBase, commands.EditEntityDocumentationAttributes
 ):
@@ -330,6 +322,10 @@ class LabelUpdateRequest(LabelsEditRequest):
     """
 
 
+class TeamEditRequest(DyffRequestBase, commands.EditTeamAttributes):
+    pass
+
+
 # ----------------------------------------------------------------------------
 
 
@@ -481,6 +477,10 @@ class ScoreQueryRequest(DyffRequestDefaultValidators):
     model: Optional[str] = pydantic.Field(default=None)
 
 
+class TeamQueryRequest(DyffEntityQueryRequest):
+    challenge: Optional[str] = pydantic.Field(default=None)
+
+
 class UseCaseQueryRequest(DyffEntityQueryRequest):
     pass
 
@@ -493,6 +493,8 @@ __all__ = [
     "ChallengeContentEditRequest",
     "ChallengeCreateRequest",
     "ChallengeTaskCreateRequest",
+    "ChallengeTaskRulesEditRequest",
+    "ChallengeTeamCreateRequest",
     "ConcernCreateRequest",
     "DyffEntityCreateRequest",
     "DyffEntityQueryRequest",
@@ -522,10 +524,14 @@ __all__ = [
     "ModelQueryRequest",
     "ModuleCreateRequest",
     "ModuleQueryRequest",
+    "PipelineCreateRequest",
+    "PipelineRunRequest",
     "QueryRequest",
     "ReportCreateRequest",
     "ReportQueryRequest",
     "SafetyCaseQueryRequest",
     "ScoreQueryRequest",
+    "TeamEditRequest",
+    "TeamQueryRequest",
     "UseCaseQueryRequest",
 ]
